===============
Mesh generation
===============

Mesh generation is not the primary objective of the library, but it is equipped with 
the most essential stuff. These are mainly for testing and representation purposes,
although what they do, they do it pretty good.


.. automodule:: sigmaepsilon.mesh.triang
    :members: triangulate


.. automodule:: sigmaepsilon.mesh.grid
    :members: